@@ -35,6 +35,7 @@ define([
 		while(typeof kernel === "undefined" || kernel === null) {
 			console.log('======sleep until kernel is ready======');
 			sleep(250);
+			kernel = Jupyter.notebook.kernel;
 		}
 		// if a dolphindb kernel is available: retrieve creds info
 		if(kernel.name === 'dolphindb') {
@@ -160,22 +161,6 @@ define([
 			return true;
 		});        
 	};
-	
-	var load_css = function(path) {
-		var link = document.createElement("link");
-		link.href = path;
-		link.type = "text/css";
-		document.getElementsByTagName("head")[0].appendChild(link);
-		console.log("==============load css: " + path + "==========");
-	};
-
-	var load_js = function(path) {
-		var script = document.createElement("script");
-		script.type = "text/javascript";
-		script.href = path;
-		document.getElementsByTagName("body")[0].appendChild(script);
-		console.log("==============load js: " + path + "==========");
-	}
 
     var dolphinDB_button = function() {
         var action = {
@@ -190,22 +175,11 @@ define([
         Jupyter.toolbar.add_buttons_group([full_action_name]);
     };
 
-	var prefix = '/home/hzzuo/.local/share/jupyter/nbextensions/dolphindb_extension/';
-
     var load_ipython_extension = function() {
         if(kernel.name === 'dolphindb') {
 			console.log(log_prefix + 'DolphinDB kernel is available -- DolphinDB_Extension initializing ');
-			// css
-			// load_css(prefix + 'codemirror/lib/codemirror.css');
-			// load_css(prefix + 'codemirror/addon/hint/show-hint.css');
 			// button
 			dolphinDB_button();
-			// js
-			// load_js(prefix + 'codemirror/lib/codemirror.js');
-			// load_js(prefix + 'codemirror/mode/sql/sql.js');
-			// load_js(prefix + 'codemirror/mode/python/python.js');
-			// load_js(prefix + 'codemirror/addon/hint/show-hint.js');
-			// load_js(prefix + 'codemirror/addon/hint/sql-hint.js');
         }
     };
 
