@@ -17,9 +17,8 @@ class DolphinDBKernel(Kernel):
     language = 'python'
     language_version = '1.0'
     language_info = {
-        'name': 'sql',
-        'mimetype': 'text/x-mysql'
-        # 'file_extension': '.py',
+        'name': 'dolphindb',
+        'mimetype': 'text/x-ddb'
     }
     banner = "DolphinDB Kernel"
     s = ddb.session()
